pub struct PhpExtractor;Implementations
Sourceimpl PhpExtractor
impl PhpExtractor
Sourcepub fn extract_routes(&self, source: &str, file_path: &str) -> Vec<Route>
pub fn extract_routes(&self, source: &str, file_path: &str) -> Vec<Route>
Extract Laravel routes from a routes/*.php file.
Sourcepub fn extract_parent_class_imports(
source: &str,
test_dir: &str,
) -> Vec<(String, Vec<String>)>
pub fn extract_parent_class_imports( source: &str, test_dir: &str, ) -> Vec<(String, Vec<String>)>
Extract import specifiers from the parent class of a test file.
Resolves the parent class to a file in the same directory, reads it,
and returns its raw use statements (unfiltered).
Only traces 1 level deep (direct parent only).
Sourcepub fn map_test_files_with_imports(
&self,
production_files: &[String],
test_sources: &HashMap<String, String>,
scan_root: &Path,
l1_exclusive: bool,
) -> Vec<FileMapping>
pub fn map_test_files_with_imports( &self, production_files: &[String], test_sources: &HashMap<String, String>, scan_root: &Path, l1_exclusive: bool, ) -> Vec<FileMapping>
Layer 1 + Layer 2 (PSR-4): Map test files to production files.